@@ -3,10 +3,13 @@ function(object, player, ...) standardGeneric("play"))
 
 setMethod("play", signature(object = "character", player = "ANY"),
 function(object, player, ...){
-    if(.Platform$OS.type == "windows" && missing(player)){
-        player <- "mplay32"
-        if(missing(...))
-            player <- paste(player, "/play /close")
+    if(missing(player)){
+        player <- getWavPlayer()
+        if(.Platform$OS.type == "windows" && is.null(player)){
+            player <- "mplay32"
+            if(missing(...))
+                player <- paste(player, "/play /close")
+        }
     }
     system(paste(player, ..., object))
 })
